import ftplib


class Nasdaq:
    """
    Represents the list of stocks traded on the Nasdaq exchange
    """

    def __init__(self):
        self.stocks = []
        with ftplib.FTP(host='ftp.nasdaqtrader.com') as ftp:
            ftp.login()
            ftp.cwd('symboldirectory')
            ftp.retrlines('RETR nasdaqlisted.txt', self.parse)

    def parse(self, line):
        line = line.split('|')
        ticker = line[0]
        name = line[1]
        etf = line[6]
        if etf == 'N':
            self.stocks.append((ticker, name))


class NYSE:
    """
    Represents the list of stocks traded on the New York Stock Exchange
    """

    def __init__(self):
        self.stocks = []
        with ftplib.FTP(host='ftp.nasdaqtrader.com') as ftp:
            ftp.login()
            ftp.cwd('symboldirectory')
            ftp.retrlines('RETR otherlisted.txt', self.parse)

    def parse(self, line):
        line = line.split('|')
        ticker = line[0]
        name = line[1]
        etf = line[4]
        if etf == 'N':
            self.stocks.append((ticker, name))


class Exchange:
    """
    Interface to return stocks listed in specified exchange.
    """

    def __init__(self, strategy='all'):
        self.strategy = strategy
        self.stock_list = []
        if strategy == 'nyse':
            nyse = NYSE()
            self.stock_list.extend(nyse.stocks)
        elif strategy == 'nasdaq':
            nasdaq = Nasdaq()
            self.stock_list.extend(nasdaq.stocks)
        else:
            nyse = NYSE()
            nasdaq = Nasdaq()
            self.stock_list.extend(nyse.stocks)
            self.stock_list.extend(nasdaq.stocks)
