from django.db import models


class Stock(models.Model):
    """
    Represents Stock lookup information.  (Name, ticker, cik)
    """
    ticker = models.CharField(max_length=10)
    name = models.CharField(max_length=255)
    cik = models.IntegerField(unique=True)
    sic = models.IntegerField()

    def __repr__(self):
        return "Stock(ticker={0}, name={1}, cik={2})".format(self.ticker,
                                                             self.name,
                                                             self.cik)

    def __hash__(self):
        return hash(self.cik)


class IndexFile(models.Model):
    """
    Represents the metadata about the SEC filing.  (Year, Quarter, filename)
    """
    filing_date = models.DateField()
    filename = models.CharField(max_length=200, unique=True)
    filing = models.CharField(max_length=6)
    company = models.ForeignKey(to=Stock)

    def __repr__(self):
        return 'IndexFile(filename={}'.format(self.filename)

    def __hash__(self):
        return hash(self.filename)


class Attribute(models.Model):
    """
    Represents an accounting attribute that has a period (duration, instant) & balance (credit,debit).
    """
    attribute = models.CharField(max_length=255)
    period = models.CharField(max_length=8)
    balance = models.CharField(max_length=6)


class AttributeValue(models.Model):
    """
    Represents the value of an attribute in a company's SEC filing.
    """
    attribute = models.ForeignKey(to=Attribute)
    value = models.IntegerField()
    index = models.ForeignKey(to=IndexFile)
